@@ -78,10 +78,10 @@ file.
 
 =head1 DESCRIPTION
 
-StreamFinder::Radionomy accepts a valid radio station URL on Radionomy.com and
-returns the actual stream URL(s) and cover art icon for that station.  
+StreamFinder::Radionomy accepts a valid radio station ID or URL on Radionomy.com 
+and returns the actual stream URL(s), title, and cover art icon for that station.  
 The purpose is that one needs one of these URLs in order to have the option to 
-stream the station in one's own choice of audio player software rather than 
+stream the station in one's own choice of media player software rather than 
 using their web browser and accepting any / all flash, ads, javascript, 
 cookies, trackers, web-bugs, and other crapware that can come with that method 
 of playing.  The author uses his own custom all-purpose media player called 
@@ -113,10 +113,10 @@ Returns an array of strings representing all stream urls found.
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
 
-Current options are:  I<-random> and I<-noplaylists>.  By default, the 
-first ("best"?) stream is returned.  If I<-random> is specified, then 
+Current options are:  I<"random"> and I<"noplaylists">.  By default, the 
+first ("best"?) stream is returned.  If I<"random"> is specified, then 
 a random one is selected from the list of streams found.  
-If I<-noplaylists> is specified, and the stream to be returned is a 
+If I<"noplaylists"> is specified, and the stream to be returned is a 
 "playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
@@ -153,7 +153,7 @@ Returns a two-element array consisting of the extension (ie. "png",
 
 =item $station->B<getType>()
 
-Returns the stream's type ("Radionomy").
+Returns the station's type ("Radionomy").
 
 =back
 
